qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH] Fix incorrect int->float conversions caught by clang -Wimplicit-


From: Fangrui Song
Subject: [PATCH] Fix incorrect int->float conversions caught by clang -Wimplicit-int-float-conversion
Date: Fri, 15 Nov 2019 17:07:31 -0800
User-agent: NeoMutt/20180223-112-0c5bf3

The warning will be enabled by default in clang 10. It is not available for 
clang <= 9.

qemu/migration/migration.c:2038:24: error: implicit conversion from 'long' to 
'double' changes value from 9223372036854775807 to 9223372036854775808 
[-Werror,-Wimplicit-int-float-conversion]
...
qemu/util/cutils.c:245:23: error: implicit conversion from 'unsigned long' to 
'double' changes value from 18446744073709550592 to 18446744073709551616 
[-Werror,-Wimplicit-int-float-conversion]

Signed-off-by: Fangrui Song <address@hidden>
---
  migration/migration.c | 4 ++--
  util/cutils.c         | 4 ++--
  2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/migration/migration.c b/migration/migration.c
index 354ad072fa..ac3ea2934a 100644
--- a/migration/migration.c
+++ b/migration/migration.c
@@ -53,6 +53,7 @@
  #include "monitor/monitor.h"
  #include "net/announce.h"
  #include "qemu/queue.h"
+#include <math.h>
  
  #define MAX_THROTTLE  (32 << 20)      /* Migration transfer speed throttling 
*/
  
@@ -2035,11 +2036,10 @@ void qmp_migrate_set_downtime(double value, Error 
**errp)
      }
  
      value *= 1000; /* Convert to milliseconds */
-    value = MAX(0, MIN(INT64_MAX, value));
  
      MigrateSetParameters p = {
          .has_downtime_limit = true,
-        .downtime_limit = value,
+        .downtime_limit = (int64_t)fmin(value, nextafter(0x1p63, 0)),
      };
  
      qmp_migrate_set_parameters(&p, errp);
diff --git a/util/cutils.c b/util/cutils.c
index fd591cadf0..2b4484c015 100644
--- a/util/cutils.c
+++ b/util/cutils.c
@@ -239,10 +239,10 @@ static int do_strtosz(const char *nptr, const char **end,
          goto out;
      }
      /*
      * Values >= 0xfffffffffffffc00 overflow uint64_t after their trip
       * through double (53 bits of precision).
       */
-    if ((val * mul >= 0xfffffffffffffc00) || val < 0) {
+    if ((val * mul > nextafter(0x1p64, 0)) || val < 0) {
          retval = -ERANGE;
          goto out;
      }
@@ -239,10 +239,10 @@ static int do_strtosz(const char *nptr, const char **end,
      }
      /*
-     * Values >= 0xfffffffffffffc00 overflow uint64_t after their trip
+     * Values > nextafter(0x1p64, 0) overflow uint64_t after their trip
       * through double (53 bits of precision).
       */
-- 
2.24.0




reply via email to

[Prev in Thread] Current Thread [Next in Thread]